# Lattice Theory
## Ordered Sets

^^^
**Partial Order** ~ Let P be a set. A \_\_\_ on P is a binary relation \(\leq\) on P that, for all \(x, y, z \in P\), satisfies the three following conditions:
    (i) **Reflexivity** - \(x \leq x\)
    (ii) **Antisymmetry** - \(x \leq y\) and \(y \leq x\) implies \(x = y\)
    (iii) **Transitivity** - \(x \leq y\) and \(y \leq z\) implies \(x \leq z\)
^^^

**Relation** ~ A \_\_\_ R on a set P is a subset \(R \subset P x P\) (cartesian product). If \(a, b \in R \to a R b\).
**(Partially) Ordered Set (poset)** ~ A set P equipped with an order relation \(\leq\) is said to be an \_\_\_.

**(Discrete/(Quasi/Pre)) Order** ~ On any set, = is an order called the \_\_\_. A relation \(\leq\) on a set P which is reflexive and transitive, but not necessarily antisymmetric is called a \_\_\_. &&An order relation \(\leq\) on P gives rise to a relation < of **strict inequality**: x < y in P if and only if \(x \leq y\) and \(x \neq y\).&&

**Non-Comparability** ~ This is a binary relation \(\parallel\) used to denote \_\_\_. We write x \(\parallel\) y if x \(\nleq\) y and y \(\nleq\) x.

**Induced Order** ~ This is when an order relation on a subset is inherited from its superset. Let P be an ordered set and let Q be a subset of P. Then Q inherits an order relation from P; given x, y ∈ Q, \(x \leq y\) in Q if and only if \(x \leq y\) in P.

**Totally Ordered Set** ~ Let P be an ordered set. Then P is a \_\_\_ if, for all \(x, y \in P\), either \(x \leq y\) or \(y \leq x\). (This is another way of saying any two elements of P are comparable). &&Alternative names for a chain are **linearly ordered set** and **chain**.&& &&On the other hand, the ordered set P is an antichain if \(x \leq y\) in P only if \(x = y\).&& &&Clearly, any subset of a chain/antichain is a chain/antichain.&& &&Let P be the n-element set {0, 1, ..., n - 1}. We write **n** to denote the chain obtained by giving P the order in which 0 < 1 < ... < n - 1 and \(\bar{n}\) for P regarded as an antichain. Any set S may be converted into an antichain \(\bar{S}\) by giving S the discrete order.

**Order-Isomorphic** ~ We say that two ordered sets P and Q are \_\_\_ and write \(P \cong Q\) if there exists a map \(\psi\) from P onto Q such that \(x \leq y\) in P if and only if \(\psi (x) \leq \psi (y)\) in Q. &&\(\psi\) is called an **order-isomorphism**&&

**Covered (Covering Relation)** ~ Let P be an ordered set and let \(x, y \in P\). We say x is \_\_\_ by y, and write \(x \prec y \text{ or } y \succ x\) if \(x < y\) and \(x \leq z < y\) implies z = x. The latter condition is demanding that there be no element z of P with x < z < y.

**Order-Isomorphic Cover-Relation Lemma** ~ Let \(P\) and \(Q\) be finite ordered sets and let \(\varphi: P \to Q\) be a bijective map. Then the following are equivalent: 1. \(\varphi\) is an order-isomorphism. 2. \(x < y\) in \(P\) if and only if \(\varphi(x) < \varphi(y)\) in \(Q\). 3. \(x \prec y\) in \(P\) if and only if \(\varphi(x) \prec \varphi(y)\) in \(Q\).

**Order-Isomorphic Diagram Proposition** ~ Two finite ordered sets P and Q are order-isomorphic if and only if they can be drawn with identical diagrams.

**The Duality Principle** ~ Given a statement \(\Phi\) about ordered sets which is true in all ordered sets, the dual statement \(\Phi^\delta\) is also true in all ordered sets. 

**Bottom and Top of an Ordered Set** ~ Let P be an ordered set. We say P has a \_\_\_ if there exists \(\bot \in P\) with the property that \(\bot R x\) for all \(x \in P\). Dually, P has a \_\_\_ element if there exists \(\top \in P\) such that \(x R \top\) for all \(x \in P\). 

**Lifted** ~ Given an ordered set P (with or without \(\bot\), form \(P_\bot\) (called P-\_\_\_) as follows: Take an element \(0 \not \in P\) and define \(\leq\) on \(P_\bot := P \cup \{0\}\) by \(x \leq y\) if and only if \(x = 0\) or \(x \leq y\) in P. 

**Maximal and Minimal Element** ~ Let P be an ordered set and let \(Q \subseteq P\). Then \(a \in Q\) is a \_\_\_ of Q if \(a R x\) and \(x \in Q\) imply \(a = x\). On the other hand, a \_\_\_ of \(Q \subseteq P\) is defined dually, by reversing the order. &&We denote the set of maximal elements of Q by max Q. If Q (with order inherited from P) has a top element, \(\top_Q\), then Max Q = \{\top_Q\}; in this case \(\top_Q\) is called the **maximum** element of Q and we write \(\top_Q\) = max Q. Same thing but for the dual, you get minimal element and the minimum element \(\bot_Q\) = Min Q&& 

**Disjoint Union of Ordered Sets** ~ Suppose P and Q are disjoint ordered sets. The \_\_\_ \(P \cup Q\) of \(P\) and \(Q\) is the ordered set formed by defining \(x R y\) in \(P \cup Q\) if and only if either \(x, y \in P\) and \(x R y\) in \(P\) or \(x, y \in Q\) and \(x R y \) in \(Q\). A diagram for \(P \cup Q\) is formed by placing side by side diagrams for \(P\) and \(Q\).
**Linear Sum of Ordered Sets** ~ Let P and Q be disjoint ordered sets. The \_\_\_ \(P \oplus Q\) is defined by taking the following order relation on \(P \cup Q : x R y \) if and only if \(\begin{array}{ll}x, y \in P \text{ and } x R y \in P \\ \text{or } x, y \in Q \text{ and } x R y \in Q \\ \text{or } x \in P \text{ and } y \in Q\end{array}\) &&We denote by \(M_n\) the sum \(1 \oplus n \oplus 1\).&&
**Cartesian Product of Ordered Sets** ~ Let \(P_1, \ldots, P_n\) be ordered sets. The \_\_\_ \(P_1 \times \cdots \times P_n\) can be made into an ordered set by imposing the coordinatewise order defined by \((x_1, \ldots, x_n) R (y_1, \ldots, y_n) \iff (\forall i)x_i R y_i\) in \(P_i\). Given an ordered set \(P\), the notation \(P^n\) is used as shorthand for \(P \times \cdots \times P\).
**Lexicographic Order** ~ This is a way to order the product of ordered sets P and Q. This is defined by \((x_1, x_2) R (y_1, y_2)\) if \(x_1 \mathcal{R} y_1\) or \((x_1 = y_1\) and \(x_2 R y_2)\).

**Down-set/Decreasing set/Order ideal** ~ Let \(P\) be an ordered set and \(Q \subseteq P\). \(Q\) is a \_\_\_ if, whenever \(x \in Q\), \(y \in P\) and \(y R x\), we have \(y \in Q\). Basically, whenever P has an element that is related to something in Q, it is also in Q. It is nice to think about it as \(Q\) is "closed under going down".
**Up-set/Increasing set/Order filter** ~ Let \(P\) be an ordered set and \(Q \subseteq P\). \(Q\) is an \_\_\_ if, whenever \(x \in Q\), \(y \in P\), and \(x R y\), we have \(y \in Q\). Basically, whenever Q has an element that is related to something in P, it is also in Q. It is nice to think about it as \(Q\) is "closed under going up".

**Principal of x** ~ Let \(P\) be an ordered set and \(x\) be an element \(x \in P\). This is the subset of \(P\) that is a downset in which every element is related to x. \(\downarrow x := \{y \in P \mid y R x\}\)

**Order-preserving** ~ Let (P, Q) and (S, R) be ordered sets. A map \(\varphi : P \mapsto S\) is \_\_\_ if \(x R y \implies \varphi(x) R \varphi(y)\). 
**Order-embedding** ~ Let (P, Q) and (S, R) be ordered sets. A map \(\varphi : P \mapsto S\) is \_\_\_ if and only if \(x R y \implies \varphi(x) R \varphi(y)\). 

**Point-wise Order** ~ Let f, g be functions which map sets X to Y. The \_\_\_ is defined such that \(f R g\) if and only if \(f(x) R g(x) \in Y \forall x \in X\). 

**Category** ~ A \_\_\_ is a class of objects and its morphisms, which are its structure-preserving maps, with an operation of composition of morphisms satisfying a set of natural conditions.

## Lattices and Complete Lattices
## Formal Concept Analysis
## Modular, Distributive, and Boolean lattices
## Representation: The Finite Case
## Congruences
## Complete Lattices and Galois Connections
## CPOs and Fixpoint Theorems
## Domains and Information Systems
## Maximality Principles
## Representation: The General Case